==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/DomainResponse.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DNSRecord;
import com.okta.sdk.resource.model.DomainCertificateMetadata;
import com.okta.sdk.resource.model.DomainCertificateSourceType;
import com.okta.sdk.resource.model.DomainLinks;
import com.okta.sdk.resource.model.DomainValidationStatus;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The properties that define an individual domain.
 */
@ApiModel(description = "The properties that define an individual domain.")
@JsonPropertyOrder({ DomainResponse.JSON_PROPERTY_BRAND_ID, DomainResponse.JSON_PROPERTY_CERTIFICATE_SOURCE_TYPE,
        DomainResponse.JSON_PROPERTY_DNS_RECORDS, DomainResponse.JSON_PROPERTY_DOMAIN, DomainResponse.JSON_PROPERTY_ID,
        DomainResponse.JSON_PROPERTY_PUBLIC_CERTIFICATE, DomainResponse.JSON_PROPERTY_VALIDATION_STATUS,
        DomainResponse.JSON_PROPERTY_LINKS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class DomainResponse implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BRAND_ID = "brandId";
    private String brandId;

    public static final String JSON_PROPERTY_CERTIFICATE_SOURCE_TYPE = "certificateSourceType";
    private DomainCertificateSourceType certificateSourceType;

    public static final String JSON_PROPERTY_DNS_RECORDS = "dnsRecords";
    private List<DNSRecord> dnsRecords = null;

    public static final String JSON_PROPERTY_DOMAIN = "domain";
    private String domain;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_PUBLIC_CERTIFICATE = "publicCertificate";
    private DomainCertificateMetadata publicCertificate;

    public static final String JSON_PROPERTY_VALIDATION_STATUS = "validationStatus";
    private DomainValidationStatus validationStatus;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private DomainLinks links;

    public DomainResponse() {
    }

    public DomainResponse brandId(String brandId) {

        this.brandId = brandId;
        return this;
    }

    /**
     * The ID number of the brand
     *
     * @return brandId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "bndul904tTZ6kWVhP0g3", value = "The ID number of the brand")
    @JsonProperty(JSON_PROPERTY_BRAND_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getBrandId() {
        return brandId;
    }

    @JsonProperty(JSON_PROPERTY_BRAND_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }

    public DomainResponse certificateSourceType(DomainCertificateSourceType certificateSourceType) {

        this.certificateSourceType = certificateSourceType;
        return this;
    }

    /**
     * Get certificateSourceType
     *
     * @return certificateSourceType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CERTIFICATE_SOURCE_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainCertificateSourceType getCertificateSourceType() {
        return certificateSourceType;
    }

    @JsonProperty(JSON_PROPERTY_CERTIFICATE_SOURCE_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCertificateSourceType(DomainCertificateSourceType certificateSourceType) {
        this.certificateSourceType = certificateSourceType;
    }

    public DomainResponse dnsRecords(List<DNSRecord> dnsRecords) {

        this.dnsRecords = dnsRecords;
        return this;
    }

    public DomainResponse adddnsRecordsItem(DNSRecord dnsRecordsItem) {
        if (this.dnsRecords == null) {
            this.dnsRecords = new ArrayList<>();
        }
        this.dnsRecords.add(dnsRecordsItem);
        return this;
    }

    /**
     * Get dnsRecords
     *
     * @return dnsRecords
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DNS_RECORDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<DNSRecord> getDnsRecords() {
        return dnsRecords;
    }

    @JsonProperty(JSON_PROPERTY_DNS_RECORDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDnsRecords(List<DNSRecord> dnsRecords) {
        this.dnsRecords = dnsRecords;
    }

    public DomainResponse domain(String domain) {

        this.domain = domain;
        return this;
    }

    /**
     * Custom domain name
     *
     * @return domain
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "login.example.com", value = "Custom domain name")
    @JsonProperty(JSON_PROPERTY_DOMAIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getDomain() {
        return domain;
    }

    @JsonProperty(JSON_PROPERTY_DOMAIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDomain(String domain) {
        this.domain = domain;
    }

    public DomainResponse id(String id) {

        this.id = id;
        return this;
    }

    /**
     * Unique ID of the domain
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "OcDz6iRyjkaCTXkdo0g3", value = "Unique ID of the domain")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setId(String id) {
        this.id = id;
    }

    public DomainResponse publicCertificate(DomainCertificateMetadata publicCertificate) {

        this.publicCertificate = publicCertificate;
        return this;
    }

    /**
     * Get publicCertificate
     *
     * @return publicCertificate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PUBLIC_CERTIFICATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainCertificateMetadata getPublicCertificate() {
        return publicCertificate;
    }

    @JsonProperty(JSON_PROPERTY_PUBLIC_CERTIFICATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPublicCertificate(DomainCertificateMetadata publicCertificate) {
        this.publicCertificate = publicCertificate;
    }

    public DomainResponse validationStatus(DomainValidationStatus validationStatus) {

        this.validationStatus = validationStatus;
        return this;
    }

    /**
     * Get validationStatus
     *
     * @return validationStatus
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VALIDATION_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainValidationStatus getValidationStatus() {
        return validationStatus;
    }

    @JsonProperty(JSON_PROPERTY_VALIDATION_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValidationStatus(DomainValidationStatus validationStatus) {
        this.validationStatus = validationStatus;
    }

    public DomainResponse links(DomainLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(DomainLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DomainResponse domainResponse = (DomainResponse) o;
        return Objects.equals(this.brandId, domainResponse.brandId)
                && Objects.equals(this.certificateSourceType, domainResponse.certificateSourceType)
                && Objects.equals(this.dnsRecords, domainResponse.dnsRecords)
                && Objects.equals(this.domain, domainResponse.domain) && Objects.equals(this.id, domainResponse.id)
                && Objects.equals(this.publicCertificate, domainResponse.publicCertificate)
                && Objects.equals(this.validationStatus, domainResponse.validationStatus)
                && Objects.equals(this.links, domainResponse.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(brandId, certificateSourceType, dnsRecords, domain, id, publicCertificate, validationStatus,
                links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DomainResponse {\n");
        sb.append("    brandId: ").append(toIndentedString(brandId)).append("\n");
        sb.append("    certificateSourceType: ").append(toIndentedString(certificateSourceType)).append("\n");
        sb.append("    dnsRecords: ").append(toIndentedString(dnsRecords)).append("\n");
        sb.append("    domain: ").append(toIndentedString(domain)).append("\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    publicCertificate: ").append(toIndentedString(publicCertificate)).append("\n");
        sb.append("    validationStatus: ").append(toIndentedString(validationStatus)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/DomainResponse.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DNSRecord;
import com.okta.sdk.resource.model.DomainCertificateMetadata;
import com.okta.sdk.resource.model.DomainCertificateSourceType;
import com.okta.sdk.resource.model.DomainLinks;
import com.okta.sdk.resource.model.DomainValidationStatus;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The properties that define an individual domain.
 */
@ApiModel(description = "The properties that define an individual domain.")
@JsonPropertyOrder({ DomainResponse.JSON_PROPERTY_BRAND_ID, DomainResponse.JSON_PROPERTY_CERTIFICATE_SOURCE_TYPE,
        DomainResponse.JSON_PROPERTY_DNS_RECORDS, DomainResponse.JSON_PROPERTY_DOMAIN, DomainResponse.JSON_PROPERTY_ID,
        DomainResponse.JSON_PROPERTY_PUBLIC_CERTIFICATE, DomainResponse.JSON_PROPERTY_VALIDATION_STATUS,
        DomainResponse.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class DomainResponse implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BRAND_ID = "brandId";
    private String brandId;

    public static final String JSON_PROPERTY_CERTIFICATE_SOURCE_TYPE = "certificateSourceType";
    private DomainCertificateSourceType certificateSourceType;

    public static final String JSON_PROPERTY_DNS_RECORDS = "dnsRecords";
    private List<DNSRecord> dnsRecords = null;

    public static final String JSON_PROPERTY_DOMAIN = "domain";
    private String domain;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_PUBLIC_CERTIFICATE = "publicCertificate";
    private DomainCertificateMetadata publicCertificate;

    public static final String JSON_PROPERTY_VALIDATION_STATUS = "validationStatus";
    private DomainValidationStatus validationStatus;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private DomainLinks links;

    public DomainResponse() {
    }

    public DomainResponse brandId(String brandId) {

        this.brandId = brandId;
        return this;
    }

    /**
     * The ID number of the brand
     *
     * @return brandId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "bndul904tTZ6kWVhP0g3", value = "The ID number of the brand")
    @JsonProperty(JSON_PROPERTY_BRAND_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getBrandId() {
        return brandId;
    }

    @JsonProperty(JSON_PROPERTY_BRAND_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }

    public DomainResponse certificateSourceType(DomainCertificateSourceType certificateSourceType) {

        this.certificateSourceType = certificateSourceType;
        return this;
    }

    /**
     * Get certificateSourceType
     *
     * @return certificateSourceType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CERTIFICATE_SOURCE_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainCertificateSourceType getCertificateSourceType() {
        return certificateSourceType;
    }

    @JsonProperty(JSON_PROPERTY_CERTIFICATE_SOURCE_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCertificateSourceType(DomainCertificateSourceType certificateSourceType) {
        this.certificateSourceType = certificateSourceType;
    }

    public DomainResponse dnsRecords(List<DNSRecord> dnsRecords) {

        this.dnsRecords = dnsRecords;
        return this;
    }

    public DomainResponse adddnsRecordsItem(DNSRecord dnsRecordsItem) {
        if (this.dnsRecords == null) {
            this.dnsRecords = new ArrayList<>();
        }
        this.dnsRecords.add(dnsRecordsItem);
        return this;
    }

    /**
     * Get dnsRecords
     *
     * @return dnsRecords
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DNS_RECORDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<DNSRecord> getDnsRecords() {
        return dnsRecords;
    }

    @JsonProperty(JSON_PROPERTY_DNS_RECORDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDnsRecords(List<DNSRecord> dnsRecords) {
        this.dnsRecords = dnsRecords;
    }

    public DomainResponse domain(String domain) {

        this.domain = domain;
        return this;
    }

    /**
     * Custom domain name
     *
     * @return domain
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "login.example.com", value = "Custom domain name")
    @JsonProperty(JSON_PROPERTY_DOMAIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getDomain() {
        return domain;
    }

    @JsonProperty(JSON_PROPERTY_DOMAIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDomain(String domain) {
        this.domain = domain;
    }

    public DomainResponse id(String id) {

        this.id = id;
        return this;
    }

    /**
     * Unique ID of the domain
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "OcDz6iRyjkaCTXkdo0g3", value = "Unique ID of the domain")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setId(String id) {
        this.id = id;
    }

    public DomainResponse publicCertificate(DomainCertificateMetadata publicCertificate) {

        this.publicCertificate = publicCertificate;
        return this;
    }

    /**
     * Get publicCertificate
     *
     * @return publicCertificate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PUBLIC_CERTIFICATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainCertificateMetadata getPublicCertificate() {
        return publicCertificate;
    }

    @JsonProperty(JSON_PROPERTY_PUBLIC_CERTIFICATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPublicCertificate(DomainCertificateMetadata publicCertificate) {
        this.publicCertificate = publicCertificate;
    }

    public DomainResponse validationStatus(DomainValidationStatus validationStatus) {

        this.validationStatus = validationStatus;
        return this;
    }

    /**
     * Get validationStatus
     *
     * @return validationStatus
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VALIDATION_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainValidationStatus getValidationStatus() {
        return validationStatus;
    }

    @JsonProperty(JSON_PROPERTY_VALIDATION_STATUS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValidationStatus(DomainValidationStatus validationStatus) {
        this.validationStatus = validationStatus;
    }

    public DomainResponse links(DomainLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(DomainLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DomainResponse domainResponse = (DomainResponse) o;
        return Objects.equals(this.brandId, domainResponse.brandId)
                && Objects.equals(this.certificateSourceType, domainResponse.certificateSourceType)
                && Objects.equals(this.dnsRecords, domainResponse.dnsRecords)
                && Objects.equals(this.domain, domainResponse.domain) && Objects.equals(this.id, domainResponse.id)
                && Objects.equals(this.publicCertificate, domainResponse.publicCertificate)
                && Objects.equals(this.validationStatus, domainResponse.validationStatus)
                && Objects.equals(this.links, domainResponse.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(brandId, certificateSourceType, dnsRecords, domain, id, publicCertificate, validationStatus,
                links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DomainResponse {\n");
        sb.append("    brandId: ").append(toIndentedString(brandId)).append("\n");
        sb.append("    certificateSourceType: ").append(toIndentedString(certificateSourceType)).append("\n");
        sb.append("    dnsRecords: ").append(toIndentedString(dnsRecords)).append("\n");
        sb.append("    domain: ").append(toIndentedString(domain)).append("\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    publicCertificate: ").append(toIndentedString(publicCertificate)).append("\n");
        sb.append("    validationStatus: ").append(toIndentedString(validationStatus)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
